/* seekerpopup.m for Winamp Classic Modern

Written by Ariszlo <ariszlo@gmail.com>

Display elapsed time in percentage of song length in a tooltip-like popup

HOW TO USE

1. Add these tags to elements.xml:

  <bitmap id="seeker.popup.border" file="images/seeker-popup.png" x="0" y="0" w="167" h="33" gammagroup="display-sui"/>
  <bitmap id="seeker.popup.bg" file="images/seeker-popup.png" x="1" y="1" w="165" h="31" gammagroup="plastic"/>

2. Copy seeker-popup.png into your images folder.

3. Add these tags to main-player.xml:

   <layer
     id="Seeker Popup Border"
     x="203" y="106"
     image="seeker.popup.border"
     alpha="0" ghost="1"
   />
   <layer
     id="Seeker Popup Background"
     x="204" y="107"
     image="seeker.popup.bg"
     alpha="0" ghost="1"
   />
   <text
     id="Playback Percentage"
     display=""
     x="207" y="112" w="159" h="22" align="center"
     fontsize="22" color="wasabi.tooltip.text"
     alpha="0" ghost="1"
   />
   <script id="seekerpopup" file="scripts/seekerpopup.maki"/>

4. Copy seekerpopup.maki into your scripts folder. */

#include "lib/std.mi"

Global Slider seekSlider;
Global Layer popupBorder, popupBg;
Global Text percentTag;
Global Timer songTimer;
Global Int percentNumber;

System.onScriptLoaded() {
  group thisGroup = getScriptGroup();
  seekSlider = thisGroup.getObject("player.slider.seek.ghost");
  popupBorder = thisGroup.getObject("Seeker Popup Border");
  popupBg = thisGroup.getObject("Seeker Popup Background");
  percentTag = thisGroup.getObject("Playback Percentage");
  popupBorder.setAlpha(0);
  popupBg.setAlpha(0);
  percentTag.setAlpha(0);

  songTimer = new Timer;
  songTimer.setDelay(1000);

  if (getPlayItemstring() != "") songTimer.start();
}

System.onPlay() {
  songTimer.start();
}

System.onStop() {
  songTimer.stop();
  percentTag.setText("");
}

songTimer.onTimer() {
  if (getPlayItemLength() > 0) {
    percentNumber = getPosition()*100/getPlayItemLength();
    percentTag.setText("Playback: " + IntegerToString(percentNumber) + " %");
  }
  else percentTag.setText("");
}

seekSlider.onEnterArea() {
  popupBorder.setAlpha(255);
  popupBg.setAlpha(255);
  percentTag.setAlpha(255);
}

seekSlider.onLeaveArea() {
  popupBorder.setAlpha(0);
  popupBg.setAlpha(0);
  percentTag.setAlpha(0);
}
